pub struct ColumnRef {
pub name: Arc<str>,
}Expand description
Reference identifying a column used inside predicates.
This is a logical column reference using only the column name. Physical binding (resolving to schema indices) happens during query planning, not at predicate construction time.
Fields
name: Arc<str>Canonical column name.
Implementations