pub struct ScalarValueRef<'a> { /* private fields */ }Expand description
Borrowed view over a scalar value backed by DynCellRef.
Implementations
Sourceimpl<'a> ScalarValueRef<'a>
impl<'a> ScalarValueRef<'a>
Sourcepub fn compare(&self, other: &ScalarValueRef<'_>) -> Option<Ordering>
pub fn compare(&self, other: &ScalarValueRef<'_>) -> Option<Ordering>
Compares this scalar with another, returning the ordering when both sides are comparable.
Sourcepub fn as_int_i128(&self) -> Option<i128>
pub fn as_int_i128(&self) -> Option<i128>
Extract as signed integer across supported widths.
Sourcepub fn as_uint_u128(&self) -> Option<u128>
pub fn as_uint_u128(&self) -> Option<u128>
Extract as unsigned integer across supported widths.
Sourcepub fn as_dyn(&self) -> DynCellRef<'a>
pub fn as_dyn(&self) -> DynCellRef<'a>
Access the underlying dynamic cell reference.
Sourcepub fn from_dyn(cell: DynCellRef<'a>) -> Self
pub fn from_dyn(cell: DynCellRef<'a>) -> Self
Construct from a dynamic cell reference.